1
0
forked from pool/virtualbox

Accepting request 224587 from Virtualization

Please accept only after pkg has built (forwarded request 224474 from saschpe)

OBS-URL: https://build.opensuse.org/request/show/224587
OBS-URL: https://build.opensuse.org/package/show/openSUSE:Factory/virtualbox?expand=0&rev=82
This commit is contained in:
Stephan Kulow 2014-03-04 21:31:18 +00:00 committed by Git OBS Bridge
commit b63d0b52e9
9 changed files with 84 additions and 58 deletions

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:cbd53cd0587acf79e1de3252ee7ba5a1594dff5e5328ab809762b32d0f84e7a7
size 62069208

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:41d03d6964931c648e3df8b14241f069d51194013e661aff7624ee264fa0995d
size 62556286

View File

@ -1,21 +1,23 @@
--- src/VBox/Devices/PC/BIOS/bios.c.orig --- src/VBox/Devices/PC/BIOS/bios.c.orig
+++ src/VBox/Devices/PC/BIOS/bios.c +++ src/VBox/Devices/PC/BIOS/bios.c
@@ -151,7 +151,7 @@ void set_mode(uint8_t mode); @@ -159,7 +159,7 @@ void set_mode(uint8_t mode);
#define BX_PCIBIOS 1 #define BX_PCIBIOS 1
#define BX_APPNAME "VirtualBox" #define BX_APPNAME "VirtualBox"

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:5d15dffc8dff6b773c6f8765c210eac599d2edf609d9e08e24132b947a2c7613
size 6245704

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:53005af22226dcd5ae8b68326602184918b5b7f8554141ae5f12f2e97dd4a62d
size 6256829

View File

@ -1,34 +0,0 @@
Index: VirtualBox-4.3.6/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
===================================================================
--- VirtualBox-4.3.6.orig/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
+++ VirtualBox-4.3.6/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
@@ -347,6 +347,20 @@ ifeq ($(KBUILD_TARGET).$(KBUILD_TARGET_A
endif
endif
+#
+# vboxvideo_drv_115
+#
+DLLS += vboxvideo_drv_115
+vboxvideo_drv_115_TEMPLATE = VBOXGUESTR3XORGMOD
+vboxvideo_drv_115_CFLAGS := $(vboxvideo_drv_70_CFLAGS)
+vboxvideo_drv_115_DEFS := $(vboxvideo_15_DEFS) XORG_VERSION_CURRENT=101500000
+vboxvideo_drv_115_INCS = \
+ $(vboxvideo_xorg_INCS) \
+ /usr/include/xorg
+vboxvideo_drv_115_INCS += $(PATH_ROOT)/src/VBox/Runtime/include
+vboxvideo_drv_115_SOURCES := $(vboxvideo_drv_15_SOURCES)
+
+
ifdef VBOX_USE_SYSTEM_XORG_HEADERS
# Build using local X.Org headers. We assume X.Org Server 1.7 or later.
DLLS := $(filter-out vboxvideo_drv_%,$(DLLS)) vboxvideo_drv_system
@@ -399,7 +413,7 @@ $$(vboxvideo_drv_0_OUTDIR)/tstvboxvideo6
$$(QUIET)$$(APPEND) -t "$$@" "done"
endef
- $(foreach ver, _70 _71 _13 _14 _15 _16 _17 _18 _19 _110 _111 _112 _113 _114, $(eval $(def_vboxvideo_test)))
+ $(foreach ver, _70 _71 _13 _14 _15 _16 _17 _18 _19 _110 _111 _112 _113 _114 _115, $(eval $(def_vboxvideo_test)))
endif # ! VBOX_ONLY_SDK
endif # eq ($(KBUILD_HOST_ARCH),$(KBUILD_TARGET_ARCH))

View File

@ -1,3 +1,64 @@
-------------------------------------------------------------------
Mon Mar 3 14:59:27 UTC 2014 - speilicke@suse.com
- Update to version 4.3.8:
+ VMM: more work on improving the emulation of certain MSR registers (e.g. bugs #12224, #12544)
+ VMM: fixed a VERR_INVALID_RPL Guru Meditation when booting certain guests (bug #11350)
+ VMM: experimental support for SSE 4.1 / SSE 4.2 passthrough, see the manual for more information how to enable it (bug #8651)
+ VMM: fix for recent Linux kernels with software virtualization
+ GUI: experimental HID LEDs synchronization for Windows hosts, see the manual for more information
+ GUI: warn the user if the Oracle Extension Pack is not installed and the user tries to activate the remote display feature (bug #9104)
+ GUI: make sure that a minimized guest (using mini toolbar in fullscreen/seamless mode) keeps the minimized state (bug #12199)
+ GUI: popup banner's "do not show this message again" check-box replaced with corresponding button
+ GUI: network adapter cables can now be connected/disconnected directly through the running virtual machine Devices / Network menu a Network status-bar indicator
+ GUI: the new VM wizard now proposes 64-bit guests on 64-bit hosts by default; better distinction between 32-bit OS types 64-bit OS types (bug #12533)
+ GUI: better error message if appliance import fails (bug #12657)
+ GUI: allow to set host-combination to 'None' using the Global settings / Input page (bug #12730)
+ GUI: don't switch the guest to a black screen during online snapshot merge (4.3 regression)
+ VBoxManage: when exporting an appliance, support the suppression of MAC addresses, which means they will be always recreated on import, avoiding duplicate MAC addresses for VMs which are imported several times
+ AHCI: fixed a VM hang during suspend under certain circumstances
+ AHCI: fixed a VM hang during online snapshot merge under certain circumstances
+ AHCI: fixed a bug which resulted in Windows XP guest hangs if a SATA CDROM is attached (bug #12417)
+ AHCI: fixed a Guru Meditation under certain conditions
+ AHCI: ejecting a CD/DVD medium failed under certain conditions
+ AHCI: disk hotplugging fixes
+ NAT: transparent handling of host sleep/resume and network configuration changes if the dnsproxy is enabled or if the hostresolver is used (bug #12441)
+ NAT: fixed crash and misbehaviour under some circumstances with ICMP packets having TTL=1
+ NAT Network: fixed IPv6 reassembly
+ NAT Network: ping proxy implemented
+ OVF: fixed reading of the OVF 0.9 section element (4.3 regression; bug #12345)
+ OVF: several fixes
+ 3D: several fixes, multiscreen fixes (e.g. bug #9124)
+ 3D: include 3D content in captured videos (bug #12666)
+ 3D: include 3D content in captured screenshot (bug #11758)
+ VGA: proper handling of legacy graphics modes if the Guest Additions are active (bug #6649)
+ USB: fixed crash during isochronous transfer under rare circumstances
+ BIOS: better disk geometry handling of SCSI drives
+ API: fix crashes in Java API clients using the XPCOM binding, happened with output parameters only (bug #11232)
+ VBoxSVC: documented the handling of host power management events (see the manual for more information) and added an extradata item for configuring the handling of the battery-low event (bug #9925)
+ VBoxSVC: fixed a bug which could trigger a crash if a VM snapshot was restored the second time and the VM has associated bandwidth groups (bug #12569)
+ VBoxSVC: properly detect ifconfig if located in /bin (bug #12713)
+ Shared Folders: fixed a failure to restore transient shared folders when starting a VM from a saved state (bug #12578)
+ Mac OS X hosts: fixed issue when the application icon was frozen in the dock if the bridging interface was not connected to a network (bug #12241)
+ Linux hosts: also consider the physical package ID when determining the number of physical CPU cores
+ Linux hosts / guests: don't warn in kernel log if memory allocation fails (bug #11171)
+ Solaris hosts: fixed the autostart SMF script (bug #11720)
+ Windows hosts: fixes for non-ANSI code page user names and similar environment contents (bug #12596)
+ Windows hosts / guests: fixed setting and using a guest user's process environment variables (relevant for Guest Control)
+ Windows Additions: fixed handle leaks in VBoxTray (bug #12563)
+ Windows Additions: fixed a crash while detecting active guest users
+ Windows Additions: fixed restoring backed up D3D files on XPDM -> WDDM upgrade
+ Guest Control: fixed setting and using a guest user's process environment variables
+ Linux Additions: support Enterprise Linux 6.5 kernels (bug #12505)
+ Linux Additions: fixed CPU hot-remove on newer Linux kernels
+ Linux / Solaris Additions: don't automount a shared folder which is already mounted
+ X11 Additions: support X.Org Server 1.15 (bug #12623)
- Rebased patches:
+ vbox-default-os-type.diff
+ vbox-no-build-dates.diff
- Dropped patches:
+ virtualbox-xorg-1.15.patch (merged upstream)
------------------------------------------------------------------- -------------------------------------------------------------------
Sun Jan 19 19:27:43 UTC 2014 - andreas.stieger@gmx.de Sun Jan 19 19:27:43 UTC 2014 - andreas.stieger@gmx.de

View File

@ -94,7 +94,7 @@ BuildRequires: xorg-x11-libXt-devel-32bit
%endif %endif
# #
ExclusiveArch: %ix86 x86_64 ExclusiveArch: %ix86 x86_64
Version: 4.3.6 Version: 4.3.8
Release: 0 Release: 0
Summary: VirtualBox is an Emulator Summary: VirtualBox is an Emulator
License: GPL-2.0+ License: GPL-2.0+
@ -146,8 +146,6 @@ Patch101: vbox-default-os-type.diff
Patch103: vbox-disable-updates.diff Patch103: vbox-disable-updates.diff
#use pie/fPIE for setuid binaries (bnc#743143) #use pie/fPIE for setuid binaries (bnc#743143)
Patch104: vbox-fpie.diff Patch104: vbox-fpie.diff
#add support for xorg-server 1.15
Patch105: virtualbox-xorg-1.15.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-build BuildRoot: %{_tmppath}/%{name}-%{version}-build
PreReq: pwdutils permissions PreReq: pwdutils permissions
Requires: %{name}-host-kmp = %version Requires: %{name}-host-kmp = %version
@ -278,10 +276,9 @@ This package contains icons for guest desktop files that were created on the des
%patch10 -p1 %patch10 -p1
%patch99 -p1 %patch99 -p1
%patch100 %patch100
%patch101 %patch101 -p1
%patch103 %patch103
%patch104 -p1 %patch104 -p1
%patch105 -p1
#copy user manual #copy user manual
%__cp %{S:1} UserManual.pdf %__cp %{S:1} UserManual.pdf
#copy kbuild config #copy kbuild config
Index: src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp --- a/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp 2014-02-25 18:08:58.000000000 +0100
=================================================================== +++ b/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp 2014-03-03 15:18:07.298245235 +0100
--- src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp.orig @@ -203,15 +203,15 @@
+++ src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
@@ -198,14 +198,14 @@ void UINameAndSystemEditor::sltFamilyCha
{
int iIndexWinXP = m_pTypeCombo->findData("WindowsXP", TypeID);
if (iIndexWinXP != -1) if (iIndexWinXP != -1)
m_pTypeCombo->setCurrentIndex(iIndexWinXP); m_pTypeCombo->setCurrentIndex(iIndexWinXP);
} }
/* Or select Ubuntu item for Linux family as default: */ - /* Or select Ubuntu item for Linux family as default: */
else if (strFamilyId == "Linux") else if (strFamilyId == "Linux")
{ {
- int iIndexUbuntu = m_pTypeCombo->findData("Ubuntu", TypeID); - QString strDefaultID = "Ubuntu";
+ int iIndexUbuntu = m_pTypeCombo->findData("OpenSUSE", TypeID); + QString strDefaultID = "openSUSE";
if (iIndexUbuntu != -1) if (ARCH_BITS == 64 && m_fSupportsHWVirtEx && m_fSupportsLongMode)
m_pTypeCombo->setCurrentIndex(iIndexUbuntu); strDefaultID += "_64";
- int iIndexUbuntu = m_pTypeCombo->findData(strDefaultID, TypeID);
- if (iIndexUbuntu != -1)
- m_pTypeCombo->setCurrentIndex(iIndexUbuntu);
+ int iIndexopenSUSE = m_pTypeCombo->findData(strDefaultID, TypeID);
+ if (iIndexopenSUSE != -1)
+ m_pTypeCombo->setCurrentIndex(iIndexopenSUSE);
} }
/* Else simply select the first one present: */ /* Else simply select the first one present: */
else m_pTypeCombo->setCurrentIndex(0); else m_pTypeCombo->setCurrentIndex(0);

View File

@ -159,7 +159,7 @@ Index: src/VBox/Devices/PC/BIOS/bios.c
=================================================================== ===================================================================
@@ -198,14 +198,14 @@ void UINameAndSystemEditor::sltFamilyCha
m_pTypeCombo->setCurrentIndex(iIndexWinXP); m_pTypeCombo->setCurrentIndex(iIndexWinXP);
} }
- /* Or select Ubuntu item for Linux family as default: */ - /* Or select Ubuntu item for Linux family as default: */
+ /* Or select OpenSUSE item for Linux family as default: */ + /* Or select openSUSE item for Linux family as default: */
else if (strFamilyId == "Linux") else if (strFamilyId == "Linux")
{ {